local L = LibStub("AceLocale-3.0"):GetLocale("HitsMode5", false)
local HitsMode5 = HitsMode5
local mod = HitsMode5:NewModule("Replay", "AceConsole-3.0")
local AceConfig = LibStub("AceConfig-3.0")
local AceConfigDialog = LibStub("AceConfigDialog-3.0")



local function copyTable(t, lookup_table)
 local copy = {}
 for i, v in pairs(t) do
  if type(v) ~= "table" then
   copy[i] = v
  else
   lookup_table = lookup_table or {}
   lookup_table[t] = copy
   if lookup_table[v] then
    copy[i] = lookup_table[v] -- We already copied this table, reuse the copy
   else
    copy[i] = copyTable(v, lookup_table) -- Not yet copied, copy it
   end
  end
 end
 return copy
end


local function copyDefaults(to, from)
 for k, v in pairs(from) do
  if type(v) == "table" then
   copyDefaults(to[k], v)
  else
   to[k] = v
  end
 end
end



local function removeOptions(t)
 for k, v in pairs(t) do
  if type(v) == "table" then
			if v.includeInReplay == false then
				t[k] = nil
				v["includeInReplay"] = nil
			else
				removeOptions(t[k], v)
			end
  else
  end
 end
end


function mod:OnInitialize()
	-- Make sure Options module is loaded
	if not HitsMode5.modules.options.loaded then
		LoadAddOn("HitsMode5_Options")
		if not HitsMode5.modules.options.loaded then
			self:Print(L["Unable to load Replay module; requires Options module"])
			return
		end
	end
	
	-- Create the message frame
	-- HitsMode5.modules.replay.messageFrame = CreateFrame("ScrollingMessageFrame", nil, UIParent)
	-- local frame = HitsMode5.modules.replay.messageFrame
	-- frame:SetPoint("CENTER")
	-- frame:SetWidth(835)
	-- frame:SetHeight(550)
	-- frame:Show()
	
	-- AceConfig:RegisterOptionsTable("HitsMode5_Replay_MessageFrame", {
		-- name = L["HitsMode5: Instant Replay"],
		-- type = "group",
		-- args = {},
	-- })
	-- AceConfigDialog:SetDefaultSize("HitsMode5_Replay_MessageFrame", 835, 550)
	--[[
	local AceGUI = LibStub("AceGUI-3.0")
	-- Create a container frame
	local f = AceGUI:Create("Frame")
	f:SetCallback("OnClose",function(widget) AceGUI:Release(widget) end)
	f:SetTitle(L["HitsMode5: Instant Replay"])
	f:SetStatusText("Replaying combat...")
	f:SetLayout("Flow")
	-- Create a button
	local btn = AceGUI:Create("ScrollingMessageFrame")
	--btn:SetWidth(170)
	--btn:SetText("Button !")
	--btn:SetCallback("OnClick", function() print("Click!") end)
	
	-- Add the button to the container
	f:AddChild(btn)
	_Test = btn
]]
	-- Create the Instant Replay filter
	HitsMode5.modules.replay.filter = HitsMode5.Filter:new()
	HitsMode5.modules.replay.filter.db = copyTable(HitsMode5.modules.replay.filterDefaults)
	local db = HitsMode5.modules.replay.filter.db
	HitsMode5.modules.replay.filter.name = L["Instant Replay"]
	HitsMode5.modules.replay.filter:UpdateFlags()
	HitsMode5.modules.replay.filter:UpdateWhiteBlackLists()
	
	-- Setup the options
	local options = copyTable(HitsMode5.modules.replay.filter:GetOptions())
	options.display.args.head.name = L["General Options"]
	
	-- Remove options that don't apply to Instant Replay
	removeOptions(options)
	
	options.start = {
		order = 1,
		type = "execute",
		name = L["Execute"],
		--desc = L["Opens all chat windows being used by HitsMode5 filters, if any are currently closed."],
		func = function()
			AceConfigDialog:CloseAll()
			AceConfigDialog:Open("HitsMode5_Replay_MessageFrame")
		end,
	}
	
	options.logPercent = {
		order = 2,
		type = "range",
		name = L["Amount to replay"],
		--desc = L["Determines how long your WoW client will retain combat log data (in seconds). This affects HitsMode5's ability to replay the combat log. Longer retention times will cause your client to use more of your RAM, but will allow you to evaluate a longer period of combat after it has happened. The default setting is 5 minutes (300 seconds). Note that this is a WoW setting, not a HitsMode5 setting. This WoW setting is normally hidden from users.\n\nWoW currently imposes a limit of 315 seconds for this value."],
		min = 0,
		max = 1,
		isPercent = true,
		get = function() return db.logPercent or 1 end,
		set = function(self, val) db.logPercent = val end,
	}
	
	options.reset = {
		order = 3,
		type = "execute",
		name = L["Reset options"],
		--desc = L["Opens all chat windows being used by HitsMode5 filters, if any are currently closed."],
		func = function()
			copyDefaults(HitsMode5.modules.replay.filter.db, HitsMode5.modules.replay.filterDefaults)
			LibStub("AceConfigRegistry-3.0"):NotifyChange("HitsMode5_Replay")
		end,
	}
	
	HitsMode5.modules.replay.options = {
		name = L["HitsMode5: Instant Replay"],
		handler = HitsMode5,
		type = "group",
		childGroups = "tab",
  args = options
 }
	
	-- Register the options table	
	AceConfig:RegisterOptionsTable("HitsMode5_Replay", HitsMode5.modules.replay.options)
	AceConfigDialog:SetDefaultSize("HitsMode5_Replay", 835, 550)
	
	-- Set us as loaded
	HitsMode5.modules.replay.loaded = true
end
	
	
	
function mod:OnEnable()
--[===[@debug@
	self:Print(L["Loaded"])
--@end-debug@]===]
end



function HitsMode5:OpenInstantReplay()
	AceConfigDialog:Open("HitsMode5_Replay")
end

